Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Build ¶
Build will return a packit.BuildFunc that will be invoked during the build phase of the buildpack lifecycle.
Build assigns the image a launch process to run the Python REPL.
func Detect ¶
func Detect() packit.DetectFunc
Detect will return a packit.DetectFunc that will be invoked during the detect phase of the buildpack lifecycle.
This buildpack will always pass detection. It will require "cpython" as launch-time build plan requirements.
Types ¶
type BuildPlanMetadata ¶
type BuildPlanMetadata struct {
// Launch flag requests the given requirement be made available during the
// launch phase of the buildpack lifecycle.
Launch bool `toml:"launch"`
}
BuildPlanMetadata is the buildpack specific data included in build plan requirements.
Click to show internal directories.
Click to hide internal directories.